@@ -21,7 +21,7 @@ def op_AGENT(state: State, name: str) -> None:
     state.require(
         is_valid_name(name), 
         f'{name} is not a correct name.', 
-        f'Names can only contain alphanumeric signs, underscores and cannot be: {print_invalid_names()}.'
+        f'Names can only contain alphanumeric characters, underscores and cannot be: {print_invalid_names()}.'
     )
     
     state.in_agent = True
